summaryrefslogtreecommitdiff
path: root/app/models/issue.rb
diff options
context:
space:
mode:
authorGitLab Bot <gitlab-bot@gitlab.com>2022-09-24 00:14:11 +0000
committerGitLab Bot <gitlab-bot@gitlab.com>2022-09-24 00:14:11 +0000
commitf70958a8932f70733e08ee1774edd28423bac59e (patch)
tree255c18df6d34de3972d4b53f1916fab05fb6f228 /app/models/issue.rb
parent0978fc4c40151a0dccbcb3d348969a6920a58e09 (diff)
downloadgitlab-ce-f70958a8932f70733e08ee1774edd28423bac59e.tar.gz
Add latest changes from gitlab-org/gitlab@master
Diffstat (limited to 'app/models/issue.rb')
-rw-r--r--app/models/issue.rb13
1 files changed, 9 insertions, 4 deletions
diff --git a/app/models/issue.rb b/app/models/issue.rb
index 153747c75df..353e12b6c5c 100644
--- a/app/models/issue.rb
+++ b/app/models/issue.rb
@@ -40,10 +40,15 @@ class Issue < ApplicationRecord
SORTING_PREFERENCE_FIELD = :issues_sort
- # Types of issues that should be displayed on lists across the app
- # for example, project issues list, group issues list and issue boards.
- # Some issue types, like test cases, should be hidden by default.
- TYPES_FOR_LIST = %w(issue incident).freeze
+ # Types of issues that should be displayed on issue lists across the app
+ # for example, project issues list, group issues list, and issues dashboard.
+ #
+ # This should be kept consistent with the enums used for the GraphQL issue list query in
+ # https://gitlab.com/gitlab-org/gitlab/-/blob/1379c2d7bffe2a8d809f23ac5ef9b4114f789c07/app/assets/javascripts/issues/list/constants.js#L154-158
+ TYPES_FOR_LIST = %w(issue incident test_case task).freeze
+
+ # Types of issues that should be displayed on issue board lists
+ TYPES_FOR_BOARD_LIST = %w(issue incident).freeze
belongs_to :project
belongs_to :namespace, inverse_of: :issues